@@ -6,7 +6,7 @@ use XSLoader;
 
 use Exporter 5.57 'import';
 
-our $VERSION     = '0.001';
+our $VERSION     = '0.002';
 our %EXPORT_TAGS = ( 'all' => [qw<
     is_scalarref is_arrayref is_hashref is_coderef is_regexpref
     is_globref is_formatref is_ioref
@@ -22,10 +22,16 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Ref::Util - Utility functions for checking references
 
+=head1 VERSION
+
+0.002
+
 =head1 DESCRIPTION
 
 Ref::Util introduces several functions to help identify references in a
